==> cms-db_v0.8.1.tar.gz: admin/codemirror.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

if ($codemirror_type == 'php') {

	$codemirror_parserfiles = array('parsexml.js',
									'parsecss.js',
									'tokenizejavascript.js',
									'parsejavascript.js',
									'../contrib/php/js/tokenizephp.js',
									'../contrib/php/js/parsephp.js',
									'../contrib/php/js/parsephphtmlmixed.js');
	$codemirror_stylesheets = array('codemirror/css/xmlcolors.css',
									'codemirror/css/jscolors.css',
									'codemirror/css/csscolors.css',
									'codemirror/contrib/php/css/phpcolors.css');

} elseif ($codemirror_type == 'html' or $codemirror_type == 'htm') {

	$codemirror_parserfiles = array('parsexml.js',
									'parsecss.js',
									'tokenizejavascript.js',
									'parsejavascript.js',
									'parsehtmlmixed.js');
	$codemirror_stylesheets = array('codemirror/css/xmlcolors.css',
									'codemirror/css/jscolors.css',
									'codemirror/css/csscolors.css');

} elseif ($codemirror_type == 'xml') {

	$codemirror_parserfiles = array('parsexml.js');
	$codemirror_stylesheets = array('codemirror/css/xmlcolors.css');

} elseif ($codemirror_type == 'js') {

	$codemirror_parserfiles = array('tokenizejavascript.js',
									'parsejavascript.js');
	$codemirror_stylesheets = array('codemirror/css/jscolors.css');

} elseif ($codemirror_type == 'css') {

	$codemirror_parserfiles = array('parsecss.js');
	$codemirror_stylesheets = array('codemirror/css/csscolors.css');

} elseif ($codemirror_type == 'py') {

	$codemirror_parserfiles = array('../contrib/python/js/parsepython.js');
	$codemirror_stylesheets = array('codemirror/contrib/python/css/pythoncolors.css');

} elseif ($codemirror_type == 'lua') {

	$codemirror_parserfiles = array('../contrib/lua/js/parselua.js');
	$codemirror_stylesheets = array('codemirror/contrib/lua/css/luacolors.css');

} elseif ($codemirror_type == 'sql') {

	$codemirror_parserfiles = array('../contrib/sql/js/parsesql.js');
	$codemirror_stylesheets = array('codemirror/contrib/sql/css/sqlcolors.css');

}

$codemirror_stylesheets[] = 'codemirror/editstyle.css';

?>
<script type="text/javascript" src="codemirror/js/codemirror.js"></script>
<!--<link rel="stylesheet" type="text/css" href="codemirror/css/docs.css"/>-->
<script type="text/javascript">
var editor = null;
window.onload = function () {
	editor = CodeMirror.fromTextArea("content", {
		height: "350px",
		parserfile: ["<?php echo implode('", "', $codemirror_parserfiles); ?>"],
		stylesheet: ["<?php echo implode('", "', $codemirror_stylesheets); ?>"],
		indentUnit: 4,
		tabMode: "shift",
		lineNumbers: true,
		path: "codemirror/js/",
		passDelay: 100, // default 200
		passTime: 50, // default 50
		continuousScanning: 150 // default 500
	});
};
// get content by editor.getCode()
</script>

==> cms-db_v0.9.tar.gz: admin/codemirror.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

if ($codemirror_type == 'php') {

	$codemirror_parserfiles = array('parsexml.js',
									'parsecss.js',
									'tokenizejavascript.js',
									'parsejavascript.js',
									'../contrib/php/js/tokenizephp.js',
									'../contrib/php/js/parsephp.js',
									'../contrib/php/js/parsephphtmlmixed.js');
	$codemirror_stylesheets = array('codemirror/css/xmlcolors.css',
									'codemirror/css/jscolors.css',
									'codemirror/css/csscolors.css',
									'codemirror/contrib/php/css/phpcolors.css');

} elseif ($codemirror_type == 'xhtml' or $codemirror_type == 'html' or $codemirror_type == 'htm') {

	$codemirror_parserfiles = array('parsexml.js',
									'parsecss.js',
									'tokenizejavascript.js',
									'parsejavascript.js',
									'parsehtmlmixed.js');
	$codemirror_stylesheets = array('codemirror/css/xmlcolors.css',
									'codemirror/css/jscolors.css',
									'codemirror/css/csscolors.css');

} elseif ($codemirror_type == 'xml') {

	$codemirror_parserfiles = array('parsexml.js');
	$codemirror_stylesheets = array('codemirror/css/xmlcolors.css');

} elseif ($codemirror_type == 'js') {

	$codemirror_parserfiles = array('tokenizejavascript.js',
									'parsejavascript.js');
	$codemirror_stylesheets = array('codemirror/css/jscolors.css');

} elseif ($codemirror_type == 'css') {

	$codemirror_parserfiles = array('parsecss.js');
	$codemirror_stylesheets = array('codemirror/css/csscolors.css');

} elseif ($codemirror_type == 'py') {

	$codemirror_parserfiles = array('../contrib/python/js/parsepython.js');
	$codemirror_stylesheets = array('codemirror/contrib/python/css/pythoncolors.css');

} elseif ($codemirror_type == 'lua') {

	$codemirror_parserfiles = array('../contrib/lua/js/parselua.js');
	$codemirror_stylesheets = array('codemirror/contrib/lua/css/luacolors.css');

} elseif ($codemirror_type == 'sql') {

	$codemirror_parserfiles = array('../contrib/sql/js/parsesql.js');
	$codemirror_stylesheets = array('codemirror/contrib/sql/css/sqlcolors.css');

} elseif ($codemirror_type == 'cs') {

	$codemirror_parserfiles = array('../contrib/csharp/js/tokenizecsharp.js',
									'../contrib/csharp/js/parsecsharp.js');
	$codemirror_stylesheets = array('codemirror/contrib/csharp/css/csharpcolors.css');

}

//$codemirror_stylesheets[] = 'codemirror/editstyle.css';

?>
<script type="text/javascript" src="codemirror/js/codemirror.js"></script>
<script type="text/javascript">
var editor = null;
window.onload = function () {
	editor = CodeMirror.fromTextArea("content", {
		height: "350px",
		parserfile: ["<?php echo implode('", "', $codemirror_parserfiles); ?>"],
		stylesheet: ["<?php echo implode('", "', $codemirror_stylesheets); ?>"],
		indentUnit: 4,
		tabMode: "shift",
		lineNumbers: true,
		path: "codemirror/js/",
		passDelay: 100, // default 200
		passTime: 50, // default 50
		continuousScanning: 150 // default 500
	});
};
// get content by editor.getCode()
</script>
